using System.Collections.Generic;
using System.IO;

namespace XamPivotGridXampl
{
    public class BucketRiskLayoutReader
    {
        private readonly string _directory;
        private readonly string _layoutFileSuffix;
        private readonly BucketRiskLayoutManager _layoutManager;

        public BucketRiskLayoutReader(string directory, string layoutFileSuffix, BucketRiskLayoutManager layoutManager)
        {
            _directory = directory;
            _layoutFileSuffix = layoutFileSuffix;
            _layoutManager = layoutManager;
        }

        public IEnumerable<BucketRiskLayoutItemViewModel> Read()
        {
            var layouts = new List<BucketRiskLayoutItemViewModel>();
            if (!Directory.Exists(_directory))
            {
                return layouts;
            }

            foreach (var file in Directory.GetFiles(_directory, "*" + _layoutFileSuffix))
            {
                var fileName = Path.GetFileName(file);
                if (!string.IsNullOrEmpty(fileName))
                {
                    var layoutName = fileName.Replace(_layoutFileSuffix, string.Empty);
                    var layoutContent = File.ReadAllText(file);

                    layouts.Add(new BucketRiskLayoutItemViewModel(layoutName, layoutContent, _layoutManager));
                }
            }

            return layouts;
        }
    }
}